summaryrefslogtreecommitdiff
path: root/src/BulletSoftBody/btSoftBody.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/BulletSoftBody/btSoftBody.h')
-rw-r--r--src/BulletSoftBody/btSoftBody.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/BulletSoftBody/btSoftBody.h b/src/BulletSoftBody/btSoftBody.h
index f91640acb..27705e600 100644
--- a/src/BulletSoftBody/btSoftBody.h
+++ b/src/BulletSoftBody/btSoftBody.h
@@ -223,10 +223,12 @@ public:
/* sCti is Softbody contact info */
struct sCti
{
- const btCollisionObject* m_colObj; /* Rigid body */
- btVector3 m_normal; /* Outward normal */
- btScalar m_offset; /* Offset from origin */
+ const btCollisionObject* m_colObj; /* Rigid body */
+ btVector3 m_normal; /* Outward normal */
+ mutable btVector3 m_impulse; /* Applied impulse */
+ btScalar m_offset; /* Offset from origin */
btVector3 m_bary; /* Barycentric weights for faces */
+ sCti() : m_impulse(0, 0, 0) {}
};
/* sMedium */
@@ -897,7 +899,7 @@ public:
int node1) const;
bool checkLink(const Node* node0,
const Node* node1) const;
- /* Check for existring face */
+ /* Check for existing face */
bool checkFace(int node0,
int node1,
int node2) const;